@@ -4,7 +4,7 @@
 # SecPanel.remoteconf - Client for Remote Account Manager
 # Shellscript for fetching and setting remote ssh access configuration
 #
-# Version SecPanel 0.5.3
+# Version SecPanel 0.6.0
 # Author: Steffen Leich <steffen.leich _at_ gmail.com>
 ##########################################################################
 
@@ -21,17 +21,18 @@ cat <<EOF
 
 	SecPanel
 	Shellscript for fetching and setting remote ssh access configuration
-	Usage: secpanel_remoteconf.sh <host> <user> <scpbin> <mode> <Runfile Timestamp>
+	Usage: secpanel_remoteconf.sh <host> <port> <user> <scpbin> <mode> <Runfile Timestamp>
 
 EOF
     exit 2
 fi
 
 HOST=$1
-USER=$2
-SCPBIN=$3
-MODE=$4
-RFTS=$5
+PORT=$2
+USER=$3
+SCPBIN=$4
+MODE=$5
+RFTS=$6
 
 cat <<EOF
 
@@ -50,14 +51,14 @@ mkdir $RF 2> /dev/null
 if [ $MODE = "read" ]
     then
 
-    $SCPBIN $USER@$HOST:.shosts $USER@$HOST:.ssh/authorized_keys $RF
-    chmod 600 $RF/authorized_keys $RF/.shosts
+    $SCPBIN -P $PORT $USER@$HOST:.shosts $USER@$HOST:.ssh/authorized_keys $RF
+    chmod 600 $RF/authorized_keys $RF/.shosts 2>/dev/null
 
 elif [ $MODE = "write" ]
     then    
 
-    $SCPBIN $RF/.shosts $USER@$HOST:
-    $SCPBIN $RF/authorized_keys $USER@$HOST:.ssh
+    $SCPBIN -P $PORT $RF/.shosts $USER@$HOST:
+    $SCPBIN -P $PORT $RF/authorized_keys $USER@$HOST:.ssh
 
 else
     echo "nothing to do..."
